package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.BankCard;

/**
 * BankCardMapper接口
 * 
 * @author ruoyi
 * @date 2023-08-06
 */
public interface BankCardMapper  extends BaseMapper<BankCard>
{
    /**
     * 查询BankCard
     * 
     * @param id BankCard主键
     * @return BankCard
     */
    public BankCard selectBankCardById(Long id);

    /**
     * 查询BankCard列表
     * 
     * @param bankCard BankCard
     * @return BankCard集合
     */
    public List<BankCard> selectBankCardList(BankCard bankCard);

    /**
     * 新增BankCard
     * 
     * @param bankCard BankCard
     * @return 结果
     */
    public int insertBankCard(BankCard bankCard);

    /**
     * 修改BankCard
     * 
     * @param bankCard BankCard
     * @return 结果
     */
    public int updateBankCard(BankCard bankCard);

    /**
     * 删除BankCard
     * 
     * @param id BankCard主键
     * @return 结果
     */
    public int deleteBankCardById(Long id);

    /**
     * 批量删除BankCard
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBankCardByIds(Long[] ids);
}
